function metricCharts(opts){

    opts = metricStarter(opts);

    // Store reference for cancellation or deferred response
    hl.chart.metricsAjax = $.ajax({ // ajax call starts
          url: "json/headlineData.json", // JQuery loads serverside.php
          data: opts,
          cache: false,
          dataType: 'json', // Choosing a JSON datatype
          success: function(response){ // Variable data contains the data we get from serverside

            prettifyMetrics(response.data.chartValues);

            $.each(response.data.chartValues, function(k,v){

              // Metric Charts JS
              //The SVG Container
              var chartSelector = "#" + k + "Metric .chart"
              var svgContainer = d3.select(chartSelector);
              var $chart = $(chartSelector);

              //The data for our line
              var lineData = v.trend;

              // Chart dimensions
              var chartWidth = $chart.width();
              var chartHeight = $chart.height();
              var dataCount = lineData.length - 1; // start at zero

              var scale = d3.scale.linear().range([chartHeight, 0]).domain(d3.extent(lineData));

              // Draw the line
              var lineFunction = d3.svg.area()
                .x(function(d,i) { return (i/dataCount) * chartWidth; })                       
                .y0(function(d) { return chartHeight; })
                .y1(function(d) { return scale(d); })
                .interpolate("basis");


              //The line SVG Path we draw
              var lineGraph = svgContainer.append("path")
                .datum(lineData)
                .attr("d", lineFunction)
                .attr("class", "area");

              // After all the drawing is done, make blocks resizable
              $chart.width("100%");
              
              metricEnder();

            });            
 
          }
      });

}

function mainChart(opts){

    if (typeof opts == "undefined"){
      opts = {};
    }
    opts = $.extend(true, hl.chart.opts, opts);

    // Start with loader, but for now just clear it
    $("#primaryChartLoader").removeClass("hidelt");
    $("#primaryChart").removeAttr("id").after("<svg id='primaryChart' class='primaryChart abs'></svg>");

    // This is for demo purposes - it should ultimately
    // be the same path with diff data params
    var jsonPath = "json/mainChartCtrData.json";
    if (opts.type == "stackedAreaChart"){
      jsonPath = "json/mainChartClickData.json";
    }

    // Cancel any previous request for data (in case user requests it multiple times)
    if (typeof hl.chart.mainChartAjax.abort !== "undefined"){
      hl.chart.mainChartAjax.abort();
    }

    // Store reference for cancellation or deferred response
    hl.chart.mainChartAjax = $.ajax({ // ajax call starts
          url: jsonPath, // JQuery loads serverside.php
          data: opts,
          cache: false,
          dataType: 'json', // Choosing a JSON datatype
          success: function(response) // Variable data contains the data we get from serverside
          {
            if (opts.type == "stackedAreaChart"){
              doStackedAreaChart(response.data.chartValues, opts);
            }
            else if (opts.type == "barChartWithTrend"){
              doBarChartWithTrend(response.data.chartValues, opts);
            }

            $("#primaryChart").prevAll().remove();
            $("#primaryChartLoader").addClass("hidelt");

          }
      });
}

function doStackedAreaChart(data, opts){
  histcatexplong = data;

  //an example of harmonizing colors between visualizations
  //observe that Consumer Discretionary and Consumer Staples have 
  //been flipped in the second chart
  var colors = d3.scale.category20c();
  keyColor = function(d, i) {return colors(d.key)};


  var chart;
  nv.addGraph(function() {
    chart = nv.models.stackedAreaChart()
                 // .width(600).height(500)
                  .useInteractiveGuideline(true)
                  .x(function(d) { return d[0] })
                  .y(function(d) { return d[1] })
                  .color(keyColor)
                  .transitionDuration(300);
                  //.clipEdge(true);

  // chart.stacked.scatter.clipVoronoi(false);

    chart.xAxis
        .tickFormat(function(d) { return d3.time.format('%m/%d')(new Date(d)) });

    chart.yAxis
        .tickFormat(d3.format('d')); // was for .2dec ,.2f

    d3.select('#primaryChart')
      .datum(histcatexplong)
      .transition().duration(0)
      .call(chart);

    nv.utils.windowResize(chart.update);

    chart.dispatch.on('stateChange', function(e) { nv.log('New State:', JSON.stringify(e)); });

    return chart;
  });

  nv.addGraph(function() {
    var chart = nv.models.stackedAreaChart()
                  .x(function(d) { return d[0] })
                  .y(function(d) { return d[1] })
                  .color(keyColor)
                  ;
                  //.clipEdge(true);

    chart.xAxis
        .tickFormat(function(d) { return d3.time.format('%x')(new Date(d)) });

    chart.yAxis
        .tickFormat(d3.format(',.2f'));

    nv.utils.windowResize(chart.update);

    return chart;
  });
}


function doBarChartWithTrend(data, opts){

  var testdata = data.map(function(series) {
      series.values = series.values.map(function(d) { return {x: d[0], y: d[1] } });
      return series;
    });

  console.log(data);

  testdata[0].type = "bar";
  testdata[0].yAxis = 1;
  testdata[1].type = "line";
  testdata[1].yAxis = 1;


  nv.addGraph(function() {
      var chart = nv.models.multiChart()
          .margin({top: 30, right: 60, bottom: 50, left: 70})
          .color(d3.scale.category10().range());

      chart.xAxis
          .tickFormat(function(d) { return d3.time.format('%m/%d')(new Date(d)) });

      chart.yAxis1
          .tickFormat(function(d) { return d.toFixed(2) + "%"; });

      d3.select('#primaryChart')
          .datum(testdata)
        .transition().duration(500).call(chart);

      return chart;
  });

}